import React, { useState } from 'react';
import axios from 'axios';
import { useRouter } from 'next/router';

interface Slide {
  slideNumber: number;
  imageUrl: string;
  audioUrl: string | null;
  videoUrl: string | null;
}

export default function Home() {
  const [pdfFile, setPdfFile] = useState<File | null>(null);
  const [zipFile, setZipFile] = useState<File | null>(null);
  const [loading, setLoading] = useState(false);
  const router = useRouter();

  const handleUpload = async () => {
    if (!pdfFile || !zipFile) {
      alert('Please select both PDF and ZIP files!');
      return;
    }


    const formData = new FormData();
    formData.append('pdf', pdfFile);
    formData.append('zip', zipFile);


    try {
      setLoading(true);
      const res = await axios.post<Slide[]>('http://localhost:3001/upload', formData, {
        headers: { 'Content-Type': 'multipart/form-data' },
        timeout: 60000, // 60 seconds for large files
      });
      console.log(res.data,'res.data')
      localStorage.setItem('slides', JSON.stringify(res.data));
      router.push('/player');
    } catch (err) {
      console.error('Upload failed:', err);
      alert('Upload failed. Please try again.');
    } finally {
      setLoading(false);
    }
  };

  return (
    <div style={styles.container}>
      <h1 style={styles.heading}>Upload Slides & Media</h1>

      <div style={styles.formGroup}>
        <label style={styles.label}>Upload PDF file:</label>
        <input type="file" accept=".pdf" onChange={(e) => setPdfFile(e.target.files?.[0] || null)} />
      </div>


      <div style={styles.formGroup}>
        <label style={styles.label}>Upload Media ZIP (mp3/mp4):</label>
        <input type="file" accept=".zip" onChange={(e) => setZipFile(e.target.files?.[0] || null)} />
      </div>

      <button onClick={handleUpload} style={styles.uploadButton} disabled={loading}>
        {loading ? 'Uploading...' : 'Start Upload'}
      </button>
    </div>
  );
}

const styles: { [key: string]: React.CSSProperties } = {
  container: {
    padding: '2rem',
    background: '#f9fafb',
    minHeight: '100vh',
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
    fontFamily: 'Segoe UI, sans-serif',
  },
  heading: {
    fontSize: '2.5rem',
    color: '#1f2937',
    marginBottom: '2rem',
    textAlign: 'center',
  },
  formGroup: {
    marginBottom: '1.5rem',
    display: 'flex',
    flexDirection: 'column',
    width: '100%',
    maxWidth: '400px',
  },
  label: {
    marginBottom: '0.5rem',
    fontSize: '1rem',
    color: '#374151',
  },
  uploadButton: {
    marginTop: '1rem',
    padding: '0.75rem 2rem',
    fontSize: '1rem',
    backgroundColor: '#2563eb',
    color: '#ffffff',
    border: 'none',
    borderRadius: 8,
    cursor: 'pointer',
    fontWeight: 'bold',
    transition: 'background-color 0.2s ease-in-out',
  },
};
